@@ -3,12 +3,10 @@ require_relative 'test_helper'
 # ServiceAccount tests
 class TestServiceAccount < MiniTest::Test
   def test_get_from_json_v1
+    stub_core_api_list
     stub_request(:get, %r{/serviceaccounts})
       .to_return(body: open_test_file('service_account.json'),
                  status: 200)
-    stub_request(:get, %r{/api/v1$})
-      .to_return(body: open_test_file('core_api_resource_list.json'),
-                 status: 200)
 
     client = Kubeclient::Client.new('http://localhost:8080/api/', 'v1')
     account = client.get_service_account('default')
